@@ -10,19 +10,19 @@ class get(View):
         self.current_page = 0
         self.length = len(pages)-1
         self.user=user
-        #self.children[0].disabled
-        self.children[1].disabled = True
+        self.children[0].disabled = True
+        if len(pages) == 1: self.children[-1].disabled = True
 
     async def update(self,page:int):
         self.current_page = page
         if page==0: 
-            #self.children[0].disabled = True
-            self.children[1].disabled = True
+            self.children[0].disabled = True
+            #self.children[1].disabled = True
             self.children[-1].disabled = False
             #self.children[-2].disabled = False
         elif page==self.length: 
-            #self.children[0].disabled = False
-            self.children[1].disabled = False
+            self.children[0].disabled = False
+            #self.children[1].disabled = False
             self.children[-1].disabled = True
             #self.children[-2].disabled = True
         else: 
@@ -58,18 +58,18 @@ class get(View):
     #async def first_page(self, interaction, button):
         #await self.show_page(0,interaction)
 
-    @ui.button(label = "before", style=discord.ButtonStyle.green)
+    @ui.button(label = "ᐊ", style=discord.ButtonStyle.grey)
     async def before_page(self, interaction, button):
         await self.show_page(self.current_page - 1,interaction)
 
-    @ui.button(label='stop', style=discord.ButtonStyle.red)
+    @ui.button(label='🗑️', style=discord.ButtonStyle.red)
     async def stop_page(self, interaction, button):
         for i in self.children:
             i.disabled = True
         await interaction.response.edit_message(view=self)
         self.stop()
 
-    @ui.button(label='next', style=discord.ButtonStyle.green)
+    @ui.button(label='ᐅ', style=discord.ButtonStyle.grey)
     async def next_page(self, interaction, button):
         await self.show_page(self.current_page + 1,interaction)
 	
